@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2019 Ericsson Telecom AB
+ * Copyright (c) 2000-2020 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -395,7 +395,7 @@ static boolean is_valid_asn1_filename(const char* file_name)
 static void usage()
 {
   fprintf(stderr, "\n"
-    "usage: %s [-abcdDeEfFgiIjlLMnNOpqrRsStuwxXyY0] [-J file] [-K file] [-z file] [-V verb_level]\n"
+    "usage: %s [-abcdDeEfFgiIjklLMnNOpqrRsStuwxXyY0] [-J file] [-K file] [-z file] [-V verb_level]\n"
     "	[-o dir] [-U none|type|'number'] [-P modulename.top_level_pdu_name] [-Q number] ...\n"
     "	[-T] module.ttcn [-A] module.asn ...\n"
     "	or  %s -v\n"
@@ -417,6 +417,7 @@ static void usage()
     "	-I:		enable real-time testing features\n"
     "	-j:		disable JSON encoder/decoder functions\n"
     "	-J file:	read input files from file\n"
+    "	-k:		enable object-oriented features\n"
     "	-K file:	enable selective code coverage\n"
     "	-l:		include source line info in C++ code\n"
     "	-L:		add source line info for logging\n"
@@ -682,10 +683,7 @@ int main(int argc, char *argv[])
         break;
       case 'k':
         SET_FLAG(k);
-        //oop_features = TRUE;
-        // disabled for the release
-        errflag = true;
-        print_usage = true;
+        oop_features = TRUE;
         break;
       case 'K':
         SET_FLAG(K);
