@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2019 Ericsson Telecom AB
+ * Copyright (c) 2000-2020 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -367,7 +367,7 @@ void FLOAT::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
       TTCN_EncDec_ErrorContext::error_internal
         ("No JSON descriptor available for type '%s'.", p_td.name);
     JSON_Tokenizer tok(va_arg(pvar, int) != 0);
-    JSON_encode(p_td, tok);
+    JSON_encode(p_td, tok, FALSE);
     p_buf.put_s(tok.get_buffer_length(), (const unsigned char*)tok.get_buffer());
     break;}
   case TTCN_EncDec::CT_OER: {
@@ -436,7 +436,7 @@ void FLOAT::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
       TTCN_EncDec_ErrorContext::error_internal
         ("No JSON descriptor available for type '%s'.", p_td.name);
     JSON_Tokenizer tok((const char*)p_buf.get_data(), p_buf.get_len());
-    if(JSON_decode(p_td, tok, FALSE)<0)
+    if(JSON_decode(p_td, tok, FALSE, FALSE)<0)
       ec.error(TTCN_EncDec::ET_INCOMPL_MSG,
                "Can not decode type '%s', because invalid or incomplete"
                " message was received"
@@ -791,12 +791,10 @@ int FLOAT::RAW_decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& buff,
   double tmp = 0.0;
   unsigned char data[16];
   RAW_coding_par cp;
-  boolean orders = FALSE;
-  if (p_td.raw->bitorderinoctet == ORDER_MSB) orders = TRUE;
+  boolean orders = p_td.raw->bitorderinoctet == ORDER_MSB;
   if (p_td.raw->bitorderinfield == ORDER_MSB) orders = !orders;
   cp.bitorder = orders ? ORDER_MSB : ORDER_LSB;
-  orders = FALSE;
-  if (p_td.raw->byteorder       == ORDER_MSB) orders = TRUE;
+  orders = p_td.raw->byteorder == ORDER_MSB;
   if (p_td.raw->bitorderinfield == ORDER_MSB) orders = !orders;
   cp.byteorder = orders ? ORDER_MSB : ORDER_LSB;
   cp.fieldorder = p_td.raw->fieldorder;
@@ -1084,7 +1082,7 @@ const char* POS_INF_STR = "\"infinity\"";
 const char* NEG_INF_STR = "\"-infinity\"";
 const char* NAN_STR = "\"not_a_number\"";
 
-int FLOAT::JSON_encode(const TTCN_Typedescriptor_t&, JSON_Tokenizer& p_tok) const
+int FLOAT::JSON_encode(const TTCN_Typedescriptor_t&, JSON_Tokenizer& p_tok, boolean) const
 {
   if (!is_bound()) {
     TTCN_EncDec_ErrorContext::error(TTCN_EncDec::ET_UNBOUND,
@@ -1114,7 +1112,7 @@ int FLOAT::JSON_encode(const TTCN_Typedescriptor_t&, JSON_Tokenizer& p_tok) cons
   return enc_len;
 }
 
-int FLOAT::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_tok, boolean p_silent, int)
+int FLOAT::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_tok, boolean p_silent, boolean, int)
 {
   bound_flag = FALSE;
   json_token_t token = JSON_TOKEN_NONE;
